AdaptationManager class

Manages the application's UI adaptations in response to emotional state changes.

This class acts as a bridge between the StateManager (which holds the user's current emotion) and the UI. It listens for emotion changes and uses a rule-based system to select an appropriate EmotionTheme to apply.

This is a ChangeNotifier, allowing widgets to subscribe to theme changes.

Inheritance

Constructors

AdaptationManager(StateManager _stateManager)

Properties

currentTheme EmotionTheme
The active EmotionTheme that the UI should be using.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
ruleEngine → RuleEngine
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
ensureReadableContrast(EmotionTheme theme) EmotionTheme
Ensures that text remains readable by checking the contrast against the surface color.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited