DraggableScrollableSheetConfig class

Configuration for SentientDraggableScrollableSheet appearance.

Annotations

Constructors

DraggableScrollableSheetConfig({required double maxChildSize, required double initialChildSize, required double minChildSize, required bool expand, required double borderRadius, required double shadowBlur, required double shadowOffset})
const

Properties

borderRadius double
The resolved border radius.
final
expand bool
Whether to allow full expansion.
final
hashCode int
The hash code for this object.
no setterinherited
initialChildSize double
The resolved initial child size.
final
maxChildSize double
The resolved maximum child size.
final
minChildSize double
The resolved minimum child size.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowBlur double
The resolved shadow blur radius.
final
shadowOffset double
The resolved shadow offset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

clean → const DraggableScrollableSheetConfig
Clean styling for disgust.
contained → const DraggableScrollableSheetConfig
Contained styling for fear.
dynamic → const DraggableScrollableSheetConfig
Dynamic styling for surprise.
flexible → const DraggableScrollableSheetConfig
Flexible styling for enjoyment.
gentle → const DraggableScrollableSheetConfig
Gentle styling for sadness.
standard → const DraggableScrollableSheetConfig
Standard styling for contempt/neutral.
structured → const DraggableScrollableSheetConfig
Structured styling for anger.