IconConfig class

Controls default size, color, and emotion-driven adjustments.

Annotations

Constructors

IconConfig({required Color color, required double size})
const

Properties

color Color
Icon color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Icon size
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lively(Color defaultColor) IconConfig
Lively style for enjoyment / surprise
neutral(Color defaultColor) IconConfig
Neutral icon style
soft(Color defaultColor) IconConfig
Soft style for sadness