SafeAreaConfig class
Defines how the SafeArea should behave for different emotional states.
- Annotations
Constructors
- SafeAreaConfig({required EdgeInsets padding})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lively → const SafeAreaConfig
- Lively state — enjoyment/surprise → tighter layout feel.
- neutral → const SafeAreaConfig
- Neutral state — balanced, default spacing.
- soft → const SafeAreaConfig
- Soft state — sadness & calm modes → more whitespace.