physics property
An optional override for the scroll physics.
If not provided, the physics are determined by the active GridViewConfig.
Implementation
final ScrollPhysics? physics;
An optional override for the scroll physics.
If not provided, the physics are determined by the active GridViewConfig.
final ScrollPhysics? physics;