SentientHeadingEnhanced class
A specialized enhanced heading widget that adapts to emotional states.
SentientHeadingEnhanced applies heavier weights and stronger visual treatments
appropriate for headings, while respecting the current emotional context.
Example Usage
SentientHeadingEnhanced(
'Big Headline',
textAlign: TextAlign.center,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SentientHeadingEnhanced
Constructors
- SentientHeadingEnhanced(String text, {Key? key, TextStyle? style, TextAlign? textAlign, int? maxLines, TextOverflow? overflow, TextEnhancedConfig? configOverride})
-
Creates a new enhanced adaptive heading.
const
Properties
- configOverride → TextEnhancedConfig?
-
An optional configuration to override the emotion-based defaults.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxLines → int?
-
The maximum number of lines for the text to span.
final
- overflow → TextOverflow?
-
How visual overflow should be handled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
Custom text style override.
final
- text → String
-
The string of text to display.
final
- textAlign → TextAlign?
-
How the text should be aligned horizontally.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited