InkWellConfig class
Base configuration for emotion-aware InkWell interaction.
- Annotations
Constructors
- InkWellConfig({required double splashIntensity, required double borderRadius, required EdgeInsets padding, Color? splashColor, Color? highlightColor})
-
const
Properties
- borderRadius → double
-
Corner radius for interaction area
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color?
-
Optional highlight color
final
- padding → EdgeInsets
-
Tap target padding
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- splashColor → Color?
-
Optional custom splash color
final
- splashIntensity → double
-
Ripple (splash) opacity or intensity
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lively → const InkWellConfig
- Lively — used for enjoyment / surprise
- neutral → const InkWellConfig
- Neutral baseline — subtle interaction
- soft → const InkWellConfig
- Soft — used for sadness / fear / contempt