ListTileConfig class
Configuration for SentientListTile appearance.
- Annotations
Constructors
- ListTileConfig({required EdgeInsetsGeometry contentPadding, required double iconSize, required TextStyle titleStyle, required TextStyle subtitleStyle, required Color tileColor, required Color iconColor, required Color textColor, required bool enableFeedback})
-
const
Properties
- contentPadding → EdgeInsetsGeometry
-
The tile's internal padding.
final
- enableFeedback → bool
-
Whether to enable ink ripple feedback.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color
-
The color of the icons.
final
- iconSize → double
-
The size of the icons (leading/trailing).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitleStyle → TextStyle
-
The style for the subtitle text.
final
- textColor → Color
-
The default text color.
final
- tileColor → Color
-
The background color of the tile.
final
- titleStyle → TextStyle
-
The style for the title text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- dynamic → const ListTileConfig
- Dynamic styling for surprise.
- expressive → const ListTileConfig
- Expressive styling for enjoyment.
- gentle → const ListTileConfig
- Gentle styling for sadness.
- minimal → const ListTileConfig
- Minimal/Stable styling for anger.
- spacious → const ListTileConfig
- Spacious styling for disgust.
- standard → const ListTileConfig
- Professional styling for contempt/neutral.