MaterialConfig class
Base configuration for emotion-aware Material widgets.
- Annotations
Constructors
- MaterialConfig({required double borderRadius, required double elevation, Color? backgroundColor, LinearGradient? backgroundGradient, Border? border, EdgeInsets padding = const EdgeInsets.all(12), Alignment alignment = Alignment.center})
-
const
Properties
- alignment → Alignment
-
Alignment for the child
final
- backgroundColor → Color?
-
Background color override (null = use emotion theme surfaceColor)
final
- backgroundGradient → LinearGradient?
-
Optional gradient background
final
- border → Border?
-
Optional border style
final
- borderRadius → double
-
Corner radius of the material surface
final
- elevation → double
-
Elevation intensity (0 = flat)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
Internal padding inside the Material wrapper
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lively → const MaterialConfig
- Lively preset (used for enjoyment/surprise)
- neutral → const MaterialConfig
- Neutral preset (baseline)
- soft → const MaterialConfig
- Soft preset (used for sadness/fear/etc.)