RotateConfig class
Base configuration for emotion-aware rotation.
- Annotations
Constructors
- RotateConfig({required double baseAngle, required double angleFactor, Alignment alignment = Alignment.center})
-
const
Properties
- alignment → Alignment
-
Alignment of the transform origin.
final
- angleFactor → double
-
Multiplier applied based on emotional intensity.
final
- baseAngle → double
-
Base rotation angle applied to the widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lively → const RotateConfig
- Lively — enjoyment/surprise → playful small rotation allowed
- neutral → const RotateConfig
- Neutral — no rotation (most stable)
- soft → const RotateConfig
- Soft — sadness/fear → avoid movement → very small rotation allowed