RowConfig class
Defines Row styling for different emotional states.
- Annotations
Constructors
Properties
- alignment → Alignment
-
Alignment of child widgets inside the container
final
- backgroundColor → Color?
-
Background color of the row container
final
- borderRadius → double
-
Corner radius of the container
final
-
boxShadow
→ List<
BoxShadow> ? -
Shadow applied around the container
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
Padding inside the row container
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited